@@ -146,6 +146,197 @@ void SMapClass::SMap ( Solver solver ) {
     }
 }
 
+//----------------------------------------------------------------
+// Generate : Recursively generate n = generateSteps predictions
+//
+//       This should be a base EDM method for Simplex & SMap.
+//       That requires virtual class members/accessor since
+//       the SMapClass::EDM object calls EDM::Generate().
+//       virtual methods & runtime deference are not splendid.
+//
+// NOTE: The EDM::SMapClass DataFrame "data" is a reference 
+//       that was instantiated in the SMap() overload 
+//       in API.cc (if data filepath provided), or, passed
+//       into SMap() overload in API.h by the pyEDM or
+//       rEDM wrappers, or direct call from cppEDM API.
+//
+//       The DataFrame contains numeric data in a valarray.
+//       Since valarray does not have push_back, a new DataFrame is
+//       constructed for each iteration of the generative projection.
+//
+//       Only implemented for univariate data with embedded = false.
+//       Not for multivariate data with embedded = true.
+//
+//----------------------------------------------------------------
+void SMapClass::Generate( Solver solver ) {
+
+#ifdef DEBUG_ALL
+    std::cout << ">>>> SMapClass:: Generate() "
+              << parameters.generateSteps << std::endl;
+    std::cout << "     data.NRows " << data.NRows() << std::endl << "     ";
+    for ( unsigned i = 0; i < data.NColumns(); i++ ) {
+        std::cout << data.ColumnNames()[i] << " ";
+    } std::cout << std::endl;
+    std::cout << "     data.Time() end: " << data.Time().back() << std::endl;
+#endif
+
+    // Override prediction to have max( 2,Tp ) points at end of data.
+    // We need Tp points if Tp > 1 to prevent nan gaps in prediction.
+    // prediction & library are zero-offset in Parameters::Validate()
+    size_t nPrediction = std::max( 2, parameters.Tp );
+
+    if ( nPrediction >= data.NRows() ) {
+        std::string errMsg("SMapClass::Generate(): Tp too large.\n");
+        throw std::runtime_error( errMsg );
+    }
+
+    size_t predStart = data.NRows() - nPrediction;
+
+    if ( predStart < 1 ) {
+        std::string errMsg("SMapClass::Generate(): "
+                           "prediction index too low.\n");
+        throw std::runtime_error( errMsg );
+    }
+
+    // Override prediction to have max(2,Tp) points at end of data
+    parameters.prediction.clear();
+    for ( size_t i = 0; i < nPrediction; i++ ) {
+        parameters.prediction.push_back( predStart + i );
+    }
+
+    std::cout << "NOTE: SMapClass::Generate(): "
+              << "prediction indices overriden to "
+              << parameters.prediction.front() + 1 << " "
+              << parameters.prediction.back()  + 1 << std::endl;
+
+    // Output DataFrame to replace projections
+    // This function over-rides the prediction indices to ensure no
+    // nan data gaps at the next time-step, even with Tp > 1.
+    // Project() returns a DataFrame with 3 rows if Tp = 1,
+    // or Tp * 2 rows if Tp > 1. The final generated DataFrame
+    // will have the original rows, plus generateSteps rows.
+    size_t nOutRows = parameters.Tp == 1 ?
+        parameters.generateSteps + 2 :
+        parameters.generateSteps + parameters.Tp;
+    DataFrame< double > generated( nOutRows, 3,
+                                   "Observations Predictions Pred_Variance" );
+    // Output DataFrame for coefficients
+    DataFrame< double > generatedCoef( nOutRows, parameters.E + 1 );
+    
+    // Output time vector
+    std::vector< std::string > generatedTime;
+
+    // Get univariate target data into columnData vector for push_back addition.
+    // At each iteration, the prediction is added to a new DataFrame
+    // that replaces the SMapClass::data object for the next Project()
+    std::valarray< double >
+        valarrayData = data.VectorColumnName( parameters.targetName );
+
+    std::vector< double > columnData;
+    columnData.assign( std::begin( valarrayData ), std::end( valarrayData ) );
+
+    // Local copy of complete data time vector for new data DataFrame
+    std::vector< std::string > dataTime( data.Time() );
+
+    //-------------------------------------------------------------------
+    // Loop for each feedback generation step
+    //-------------------------------------------------------------------
+    for ( int step = 0; step < (int) parameters.generateSteps; step++ ) {
+
+        // 1) Generate prediction --------------------------------------
+        Project( solver );
+
+        std::valarray< double > newPredictions =
+            projection.VectorColumnName( "Predictions" );
+
+        double      newPrediction = newPredictions   [ nPrediction ];
+        std::string newTime       = projection.Time()[ nPrediction ];
+
+#ifdef DEBUG_ALL
+        projection.MaxRowPrint() = 10;
+        std::cout << "+++++++ newTime " << newTime
+                  << " newPredict " << newPrediction << " +++++++" << std::endl;
+        std::cout << "+++++++ projection " << step << " +++++++" << std::endl;
+        std::cout << projection;
+        std::cout << "+++++++ coefficients " << step << " +++++++" << std::endl;
+        std::cout << coefficients;
+#endif
+
+        // 2) Save prediction in generated -----------------------------
+        if ( step == 0 ) {
+            // Existing obervations
+            for ( size_t j = 0; j < nPrediction; j++ ) {
+                generated.WriteRow( j, projection.Row( j ) );
+                generatedTime.push_back( projection.Time()[ j ] );
+
+                generatedCoef.WriteRow( j, coefficients.Row( j ) );
+            }
+        }
+        // The 1-step ahead prediction
+        generated.WriteRow( nPrediction + step,
+                            projection.Row( nPrediction ) );
+
+        generatedCoef.WriteRow( nPrediction + step,
+                                coefficients.Row( nPrediction ) );
+
+        generatedTime.push_back( newTime );
+
+        // 3) Increment library by adding another row index ------------
+        parameters.library.push_back( parameters.library.back() + 1 );
+
+        // 4) Increment prediction indices -----------------------------
+        for ( auto pi  = parameters.prediction.begin();
+                   pi != parameters.prediction.end(); pi++ ) {
+            *pi = *pi + 1;
+        }
+
+        //--------------------------------------------------------------
+        // 5) Add 1-step ahead projection to data for next Project()
+        //    Create newDF DataFrame with columnData.size + 1 rows, 1 column
+        DataFrame< double > newDF( columnData.size() + 1, 1,
+                                   parameters.columnNames.front() );
+
+        // Add prediction time
+        dataTime.push_back( newTime );
+        newDF.Time()     = dataTime;
+        newDF.TimeName() = data.TimeName();
+
+        // Append projection to columnData
+        columnData.push_back( newPrediction );
+        // Convert to valarray and write to newData DataFrame
+        std::valarray< double > newData( columnData.data(), columnData.size() );
+        newDF.WriteColumn( 0, newData );
+
+        //--------------------------------------------------------------
+        // 6) Replace SMapClass.data with newDF for next Project()
+        this->data = newDF; // JP is this a leak?
+
+#ifdef DEBUG_ALL
+        std::cout << "+++++++ newDF " << step << " +++++++" << std::endl;
+        newDF.MaxRowPrint() = 5;
+        std::cout << newDF;
+#endif
+    }
+
+    // 7) Replace SMapClass.projection, coefficients with generated
+    generated.Time()            = generatedTime;
+    generated.TimeName()        = data.TimeName();
+    generatedCoef.Time()        = generatedTime;
+    generatedCoef.TimeName()    = data.TimeName();
+    generatedCoef.ColumnNames() = coefficients.ColumnNames();
+    generatedCoef.BuildColumnNameIndex();
+
+    projection   = generated;     // JP is this a leak?
+    coefficients = generatedCoef; // JP is this a leak?
+
+#ifdef DEBUG_ALL
+    std::cout << "+++++++ generated +++++++" << std::endl;
+    generated.MaxRowPrint() = generated.NRows();
+    std::cout << generated;
+    std::cout << "<<<< SMapClass:: Generate()" << std::endl;
+#endif
+}
+
 //----------------------------------------------------------------
 // 
 //----------------------------------------------------------------
